---
outline: [2, 4]
---
# Browser <Badge type="tip" text="^0.3.0" />

Package used on a browser-side of your Rage:MP Server

## Usage

```ts
import { fw } from '@entityseven/rage-fw-browser'
```

Only usable in Browser environment. For usage in [Server](./server) and [Client](./client) refer to their docs

## Declaration

```ts
fw = {
  event: Browser,
  rpc: Rpc
}
```

Further documentation will describe the fields included in `fw`

## Browser

Browser-side interactions

### debugLogs

Setter. Enables console debug logs for events

```ts
fw.event.debugLogs = true
```

### customLogger

Setter. Enables console debug logs for events

```ts
fw.event.customLogger =
  () =>
  (method: string, eventName: string, ...args: unknown[]) => {
    // log with desired formatting
  }
```

### register

Registers a browser event with an associated callback

```ts
fw.event.register('showNotification', (message, color) => {
  // do something
})
```

### unregister

Unregisters a browser event, removing the associated callback

```ts
fw.event.unregister('showNotification')
```

### trigger

Triggers a browser event from the browser with arguments from shared types. Formerly known as `call` or `emit`

```ts
// without args
fw.event.trigger('browserEventName')
// with args
fw.event.trigger('browserEventName', ['message to me'])
```

### triggerServer

Triggers a server event from the browser with arguments from shared types. Formerly known as `callServer` or `emitServer`

```ts
// without args
fw.event.triggerServer('serverEventName')
// with args
fw.event.triggerServer('serverEventName', ['message to server'])
```

### triggerClient

Triggers a client event from the browser with arguments from shared types. Formerly known as `callClient` or `emitClient`

```ts
// without args
fw.event.triggerClient('clientEventName')
// with args
fw.event.triggerClient('clientEventName', ['message to client'])
```

### Rpc

`rage-fw-rpc` instance used under the hood. It is highly recommended to use this one if you need it instead of creating a new instance

#### `forceBrowserDevMode`?

`rage-fw-rpc` has a setting which enables it to be ran in browser dev mode without MP context ([see Rpc Config](/rage-fw-rpc/#rpc-config)). As `rage-fw-browser` does not expose Rpc constructor, you can use `.env` with `RageFW_forceBrowserDevMode=true` to enable it
